==> mpqc_2.0.4.orig.tar.gz: mpqc-2.0.4.orig/src/lib/chemistry/qc/oint3/i3311AB.cc <==
#include <chemistry/qc/oint3/build.h>
int BuildIntV3::i3311eAB(){
/* the cost is 258 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
double t17;
double t18;
double t19;
double t20;
double t21;
double t22;
double t23;
double t24;
double t25;
double t26;
double t27;
double t28;
double t29;
double t30;
double t31;
double t32;
double t33;
double t34;
double t35;
double t36;
double t37;
double t38;
double t39;
double t40;
double t41;
double t42;
double t43;
double t44;
double t45;
double t46;
double t47;
double t48;
double t49;
double t50;
double t51;
double t52;
t1=int_v_zeta34*int_v_ooze;
t2=int_v_oo2zeta12*t1;
t1=(-1)*t2;
double***int_v_list0=int_v_list(0);
double**int_v_list00=int_v_list0[0];
double*int_v_list002=int_v_list00[2];
t2=t1*int_v_list002[0];
double*int_v_list001=int_v_list00[1];
t3=int_v_oo2zeta12*int_v_list001[0];
t4=t3+t2;
t2=int_v_W0-int_v_p120;
double*int_v_list003=int_v_list00[3];
t3=t2*int_v_list003[0];
t5=t2*t3;
t6=t5+t4;
t5=0.5*int_v_ooze;
t7=t5*t6;
t6=t5*int_v_list002[0];
t8=int_v_W0-int_v_p340;
t9=t8*int_v_list003[0];
t10=int_v_p340-int_v_r30;
t11=t10*int_v_list002[0];
t12=t11+t9;
t9=t2*t12;
t11=t9+t6;
t9=2*int_v_ooze;
t13=int_v_zeta34*t9;
t9=int_v_oo2zeta12*t13;
t13=(-1)*t9;
t9=t13*t11;
t14=t9+t7;
t9=t5*int_v_list001[0];
t15=t8*int_v_list002[0];
t16=t10*int_v_list001[0];
t17=t16+t15;
t15=t2*t17;
t16=t15+t9;
t15=int_v_oo2zeta12*2;
t18=t15*t16;
t19=t18+t14;
t14=t5*t3;
t18=t1*t12;
t20=t18+t14;
t21=int_v_oo2zeta12*t17;
t22=t21+t20;
t20=t5*int_v_list003[0];
double*int_v_list004=int_v_list00[4];
t23=t8*int_v_list004[0];
t8=t10*int_v_list003[0];
t10=t8+t23;
t8=t2*t10;
t23=t8+t20;
t8=t2*t23;
t24=t8+t22;
t8=t2*t24;
t22=t8+t19;
double***int_v_list3=int_v_list(3);
double**int_v_list31=int_v_list3[1];
double*int_v_list310=int_v_list31[0];
int_v_list310[29]=t22;
t8=int_v_W2-int_v_p342;
t19=t8*int_v_list003[0];
t25=int_v_p342-int_v_r32;
t26=t25*int_v_list002[0];
t27=t26+t19;
t19=t2*t27;
t26=t13*t19;
t28=t8*int_v_list002[0];
t29=t25*int_v_list001[0];
t30=t29+t28;
t28=t2*t30;
t29=t15*t28;
t31=t29+t26;
t26=t1*t27;
t29=int_v_oo2zeta12*t30;
t32=t29+t26;
t33=t8*int_v_list004[0];
t8=t25*int_v_list003[0];
t25=t8+t33;
t8=t2*t25;
t33=t2*t8;
t34=t33+t32;
t33=t2*t34;
t35=t33+t31;
int_v_list310[28]=t35;
t31=int_v_W1-int_v_p341;
t33=t31*int_v_list003[0];
t36=int_v_p341-int_v_r31;
t37=t36*int_v_list002[0];
t38=t37+t33;
t33=t2*t38;
t37=t13*t33;
t39=t31*int_v_list002[0];
t40=t36*int_v_list001[0];
t41=t40+t39;
t39=t2*t41;
t40=t15*t39;
t42=t40+t37;
t37=t1*t38;
t40=int_v_oo2zeta12*t41;
t43=t40+t37;
t44=t31*int_v_list004[0];
t31=t36*int_v_list003[0];
t36=t31+t44;
t31=t2*t36;
t44=t2*t31;
t45=t44+t43;
t44=t2*t45;
t2=t44+t42;
int_v_list310[27]=t2;
t42=int_v_W2-int_v_p122;
t44=t42*t24;
int_v_list310[26]=t44;
t46=t42*t34;
t47=t7+t46;
int_v_list310[25]=t47;
t46=t42*t45;
int_v_list310[24]=t46;
t48=int_v_W1-int_v_p121;
t49=t24*t48;
int_v_list310[23]=t49;
t24=t48*t34;
int_v_list310[22]=t24;
t34=t48*t45;
t45=t7+t34;
int_v_list310[21]=t45;
t7=t1*t11;
t11=int_v_oo2zeta12*t16;
t16=t11+t7;
t7=t42*t23;
t11=t42*t7;
t7=t11+t16;
int_v_list310[20]=t7;
t11=t42*t3;
t34=t5*t11;
t11=t1*t19;
t19=t11+t34;
t34=int_v_oo2zeta12*t28;
t28=t34+t19;
t19=t42*t8;
t50=t14+t19;
t19=t42*t50;
t50=t19+t28;
int_v_list310[19]=t50;
t19=t1*t33;
t28=int_v_oo2zeta12*t39;
t33=t28+t19;
t39=t42*t31;
t51=t42*t39;
t39=t51+t33;
int_v_list310[18]=t39;
t33=t48*t23;
t23=t42*t33;
int_v_list310[17]=t23;
t51=t48*t3;
t3=t5*t51;
t51=t48*t8;
t8=t42*t51;
t52=t8+t3;
int_v_list310[16]=t52;
t8=t48*t31;
t31=t14+t8;
t8=t42*t31;
int_v_list310[15]=t8;
t14=t48*t33;
t33=t16+t14;
int_v_list310[14]=t33;
t14=t34+t11;
t11=t48*t51;
t16=t11+t14;
int_v_list310[13]=t16;
t11=t19+t3;
t3=t28+t11;
t11=t48*t31;
t14=t11+t3;
int_v_list310[12]=t14;
t3=t42*t12;
t11=t13*t3;
t3=t42*t17;
t19=t15*t3;
t3=t19+t11;
t11=t21+t18;
t18=t42*t10;
t19=t42*t18;
t18=t19+t11;
t19=t42*t18;
t18=t19+t3;
int_v_list310[11]=t18;
t3=t42*t27;
t19=t6+t3;
t3=t13*t19;
t19=t42*int_v_list003[0];
t21=t42*t19;
t28=t4+t21;
t21=t5*t28;
t28=t21+t3;
t3=t42*t30;
t21=t9+t3;
t3=t15*t21;
t21=t3+t28;
t3=t5*t19;
t19=t26+t3;
t3=t29+t19;
t19=t42*t25;
t26=t20+t19;
t19=t42*t26;
t26=t19+t3;
t3=t42*t26;
t19=t3+t21;
int_v_list310[10]=t19;
t3=t42*t38;
t21=t13*t3;
t3=t42*t41;
t26=t15*t3;
t3=t26+t21;
t21=t42*t36;
t26=t42*t21;
t21=t43+t26;
t26=t42*t21;
t21=t26+t3;
int_v_list310[9]=t21;
t3=t48*t12;
t12=t1*t3;
t26=t48*t17;
t17=int_v_oo2zeta12*t26;
t28=t17+t12;
t12=t48*t10;
t10=t42*t12;
t17=t42*t10;
t10=t17+t28;
int_v_list310[8]=t10;
t17=t48*t27;
t27=t1*t17;
t28=t48*int_v_list003[0];
t29=t42*t28;
t31=t5*t29;
t29=t31+t27;
t27=t48*t30;
t30=int_v_oo2zeta12*t27;
t31=t30+t29;
t29=t48*t25;
t25=t42*t29;
t30=t5*t28;
t34=t30+t25;
t25=t42*t34;
t34=t25+t31;
int_v_list310[7]=t34;
t25=t48*t38;
t31=t6+t25;
t6=t1*t31;
t1=t48*t41;
t25=t9+t1;
t1=int_v_oo2zeta12*t25;
t9=t1+t6;
t1=t48*t36;
t6=t20+t1;
t1=t42*t6;
t20=t42*t1;
t1=t20+t9;
int_v_list310[6]=t1;
t9=t48*t12;
t12=t11+t9;
t9=t42*t12;
int_v_list310[5]=t9;
t11=t48*t29;
t20=t32+t11;
t11=t42*t20;
t29=t48*t28;
t28=t4+t29;
t4=t5*t28;
t5=t4+t11;
int_v_list310[4]=t5;
t11=t37+t30;
t28=t40+t11;
t11=t48*t6;
t6=t11+t28;
t11=t42*t6;
int_v_list310[3]=t11;
t28=t13*t3;
t3=t15*t26;
t26=t3+t28;
t3=t48*t12;
t12=t3+t26;
int_v_list310[2]=t12;
t3=t13*t17;
t17=t15*t27;
t26=t17+t3;
t3=t48*t20;
t17=t3+t26;
int_v_list310[1]=t17;
t3=t13*t31;
t13=t4+t3;
t3=t15*t25;
t4=t3+t13;
t3=t48*t6;
t6=t3+t4;
int_v_list310[0]=t6;
return 1;}

==> mpqc_2.3.1.orig.tar.gz: mpqc-2.3.1/src/lib/chemistry/qc/oint3/i3311AB.cc <==
#include <chemistry/qc/oint3/build.h>
int sc::BuildIntV3::i3311eAB(){
/* the cost is 258 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
double t17;
double t18;
double t19;
double t20;
double t21;
double t22;
double t23;
double t24;
double t25;
double t26;
double t27;
double t28;
double t29;
double t30;
double t31;
double t32;
double t33;
double t34;
double t35;
double t36;
double t37;
double t38;
double t39;
double t40;
double t41;
double t42;
double t43;
double t44;
double t45;
double t46;
double t47;
double t48;
double t49;
double t50;
double t51;
double t52;
t1=int_v_zeta34*int_v_ooze;
t2=int_v_oo2zeta12*t1;
t1=(-1)*t2;
double***restrictxx int_v_list0=int_v_list(0);
double**restrictxx int_v_list00=int_v_list0[0];
double*restrictxx int_v_list002=int_v_list00[2];
t2=t1*int_v_list002[0];
double*restrictxx int_v_list001=int_v_list00[1];
t3=int_v_oo2zeta12*int_v_list001[0];
t4=t3+t2;
t2=int_v_W0-int_v_p120;
double*restrictxx int_v_list003=int_v_list00[3];
t3=t2*int_v_list003[0];
t5=t2*t3;
t6=t5+t4;
t5=0.5*int_v_ooze;
t7=t5*t6;
t6=t5*int_v_list002[0];
t8=int_v_W0-int_v_p340;
t9=t8*int_v_list003[0];
t10=int_v_p340-int_v_r30;
t11=t10*int_v_list002[0];
t12=t11+t9;
t9=t2*t12;
t11=t9+t6;
t9=2*int_v_ooze;
t13=int_v_zeta34*t9;
t9=int_v_oo2zeta12*t13;
t13=(-1)*t9;
t9=t13*t11;
t14=t9+t7;
t9=t5*int_v_list001[0];
t15=t8*int_v_list002[0];
t16=t10*int_v_list001[0];
t17=t16+t15;
t15=t2*t17;
t16=t15+t9;
t15=int_v_oo2zeta12*2;
t18=t15*t16;
t19=t18+t14;
t14=t5*t3;
t18=t1*t12;
t20=t18+t14;
t21=int_v_oo2zeta12*t17;
t22=t21+t20;
t20=t5*int_v_list003[0];
double*restrictxx int_v_list004=int_v_list00[4];
t23=t8*int_v_list004[0];
t8=t10*int_v_list003[0];
t10=t8+t23;
t8=t2*t10;
t23=t8+t20;
t8=t2*t23;
t24=t8+t22;
t8=t2*t24;
t22=t8+t19;
double***restrictxx int_v_list3=int_v_list(3);
double**restrictxx int_v_list31=int_v_list3[1];
double*restrictxx int_v_list310=int_v_list31[0];
int_v_list310[29]=t22;
t8=int_v_W2-int_v_p342;
t19=t8*int_v_list003[0];
t25=int_v_p342-int_v_r32;
t26=t25*int_v_list002[0];
t27=t26+t19;
t19=t2*t27;
t26=t13*t19;
t28=t8*int_v_list002[0];
t29=t25*int_v_list001[0];
t30=t29+t28;
t28=t2*t30;
t29=t15*t28;
t31=t29+t26;
t26=t1*t27;
t29=int_v_oo2zeta12*t30;
t32=t29+t26;
t33=t8*int_v_list004[0];
t8=t25*int_v_list003[0];
t25=t8+t33;
t8=t2*t25;
t33=t2*t8;
t34=t33+t32;
t33=t2*t34;
t35=t33+t31;
int_v_list310[28]=t35;
t31=int_v_W1-int_v_p341;
t33=t31*int_v_list003[0];
t36=int_v_p341-int_v_r31;
t37=t36*int_v_list002[0];
t38=t37+t33;
t33=t2*t38;
t37=t13*t33;
t39=t31*int_v_list002[0];
t40=t36*int_v_list001[0];
t41=t40+t39;
t39=t2*t41;
t40=t15*t39;
t42=t40+t37;
t37=t1*t38;
t40=int_v_oo2zeta12*t41;
t43=t40+t37;
t44=t31*int_v_list004[0];
t31=t36*int_v_list003[0];
t36=t31+t44;
t31=t2*t36;
t44=t2*t31;
t45=t44+t43;
t44=t2*t45;
t2=t44+t42;
int_v_list310[27]=t2;
t42=int_v_W2-int_v_p122;
t44=t42*t24;
int_v_list310[26]=t44;
t46=t42*t34;
t47=t7+t46;
int_v_list310[25]=t47;
t46=t42*t45;
int_v_list310[24]=t46;
t48=int_v_W1-int_v_p121;
t49=t24*t48;
int_v_list310[23]=t49;
t24=t48*t34;
int_v_list310[22]=t24;
t34=t48*t45;
t45=t7+t34;
int_v_list310[21]=t45;
t7=t1*t11;
t11=int_v_oo2zeta12*t16;
t16=t11+t7;
t7=t42*t23;
t11=t42*t7;
t7=t11+t16;
int_v_list310[20]=t7;
t11=t42*t3;
t34=t5*t11;
t11=t1*t19;
t19=t11+t34;
t34=int_v_oo2zeta12*t28;
t28=t34+t19;
t19=t42*t8;
t50=t14+t19;
t19=t42*t50;
t50=t19+t28;
int_v_list310[19]=t50;
t19=t1*t33;
t28=int_v_oo2zeta12*t39;
t33=t28+t19;
t39=t42*t31;
t51=t42*t39;
t39=t51+t33;
int_v_list310[18]=t39;
t33=t48*t23;
t23=t42*t33;
int_v_list310[17]=t23;
t51=t48*t3;
t3=t5*t51;
t51=t48*t8;
t8=t42*t51;
t52=t8+t3;
int_v_list310[16]=t52;
t8=t48*t31;
t31=t14+t8;
t8=t42*t31;
int_v_list310[15]=t8;
t14=t48*t33;
t33=t16+t14;
int_v_list310[14]=t33;
t14=t34+t11;
t11=t48*t51;
t16=t11+t14;
int_v_list310[13]=t16;
t11=t19+t3;
t3=t28+t11;
t11=t48*t31;
t14=t11+t3;
int_v_list310[12]=t14;
t3=t42*t12;
t11=t13*t3;
t3=t42*t17;
t19=t15*t3;
t3=t19+t11;
t11=t21+t18;
t18=t42*t10;
t19=t42*t18;
t18=t19+t11;
t19=t42*t18;
t18=t19+t3;
int_v_list310[11]=t18;
t3=t42*t27;
t19=t6+t3;
t3=t13*t19;
t19=t42*int_v_list003[0];
t21=t42*t19;
t28=t4+t21;
t21=t5*t28;
t28=t21+t3;
t3=t42*t30;
t21=t9+t3;
t3=t15*t21;
t21=t3+t28;
t3=t5*t19;
t19=t26+t3;
t3=t29+t19;
t19=t42*t25;
t26=t20+t19;
t19=t42*t26;
t26=t19+t3;
t3=t42*t26;
t19=t3+t21;
int_v_list310[10]=t19;
t3=t42*t38;
t21=t13*t3;
t3=t42*t41;
t26=t15*t3;
t3=t26+t21;
t21=t42*t36;
t26=t42*t21;
t21=t43+t26;
t26=t42*t21;
t21=t26+t3;
int_v_list310[9]=t21;
t3=t48*t12;
t12=t1*t3;
t26=t48*t17;
t17=int_v_oo2zeta12*t26;
t28=t17+t12;
t12=t48*t10;
t10=t42*t12;
t17=t42*t10;
t10=t17+t28;
int_v_list310[8]=t10;
t17=t48*t27;
t27=t1*t17;
t28=t48*int_v_list003[0];
t29=t42*t28;
t31=t5*t29;
t29=t31+t27;
t27=t48*t30;
t30=int_v_oo2zeta12*t27;
t31=t30+t29;
t29=t48*t25;
t25=t42*t29;
t30=t5*t28;
t34=t30+t25;
t25=t42*t34;
t34=t25+t31;
int_v_list310[7]=t34;
t25=t48*t38;
t31=t6+t25;
t6=t1*t31;
t1=t48*t41;
t25=t9+t1;
t1=int_v_oo2zeta12*t25;
t9=t1+t6;
t1=t48*t36;
t6=t20+t1;
t1=t42*t6;
t20=t42*t1;
t1=t20+t9;
int_v_list310[6]=t1;
t9=t48*t12;
t12=t11+t9;
t9=t42*t12;
int_v_list310[5]=t9;
t11=t48*t29;
t20=t32+t11;
t11=t42*t20;
t29=t48*t28;
t28=t4+t29;
t4=t5*t28;
t5=t4+t11;
int_v_list310[4]=t5;
t11=t37+t30;
t28=t40+t11;
t11=t48*t6;
t6=t11+t28;
t11=t42*t6;
int_v_list310[3]=t11;
t28=t13*t3;
t3=t15*t26;
t26=t3+t28;
t3=t48*t12;
t12=t3+t26;
int_v_list310[2]=t12;
t3=t13*t17;
t17=t15*t27;
t26=t17+t3;
t3=t48*t20;
t17=t3+t26;
int_v_list310[1]=t17;
t3=t13*t31;
t13=t4+t3;
t3=t15*t25;
t4=t3+t13;
t3=t48*t6;
t6=t3+t4;
int_v_list310[0]=t6;
return 1;}
